@@ -13,143 +13,218 @@
 #'
 #' @param info A List. Contains a set of in a *.info file.
 #' @param verbose Logical.
-#' @param maximization Logical. Whether the underlying optimization algorithm performs a maximization? 
+#' @param maximization Logical. Whether the underlying optimization algorithm performs a maximization?
 #' Set to NULL to determine automatically based on format
 #' @param format A character. The format of data source, either 'IOHProfiler', 'COCO' or 'TWO_COL"
 #' @param subsampling Logical. Whether *.cdat files are subsampled?
+#'
 #' @return A S3 object 'DataSet'
 #' @export
-#' @examples 
-#' path <- system.file("extdata", "ONE_PLUS_LAMDA_EA", package="IOHanalyzer")
-#' info <- read_IndexFile(file.path(path,"IOHprofiler_f1_i1.info"))
+#' @examples
+#' path <- system.file('extdata', 'ONE_PLUS_LAMDA_EA', package = 'IOHanalyzer')
+#' info <- read_index_file(file.path(path, 'IOHprofiler_f1_i1.info'))
 #' DataSet(info[[1]])
 DataSet <- function(info, verbose = F, maximization = NULL, format = IOHprofiler,
                     subsampling = FALSE) {
   if (!is.null(info)) {
-    datFile <- info$datafile
     path <- dirname(info$datafile)
-    filename <- basename(info$datafile)
+    suite <- toupper(info$suite)
 
-    # Data source:
-    # alignment by target values:
-    #   IOHprofiler: *.dat
-    #   COCO: *.dat
-    # alignment by runtimes:
-    #   IHprofiler: *.cdat
-    #   COCO: *.tdat
-    if (format == IOHprofiler) {
-      datFile <- file.path(path, paste0(strsplit(filename, '\\.')[[1]][1], '.dat'))
-      tdatFile <- file.path(path, paste0(strsplit(filename, '\\.')[[1]][1], '.tdat'))
-      cdatFile <- file.path(path, paste0(strsplit(filename, '\\.')[[1]][1], '.cdat'))
-
-      # priority for the runtime alignment: *.cdat > *.tdat > *.dat
-      cdatFile <- ifelse(file.exists(cdatFile), cdatFile, tdatFile)
-      cdatFile <- ifelse(file.exists(cdatFile), cdatFile, datFile)
-    } else if (format %in% c(COCO, BIBOJ_COCO)) {
-      datFile <- file.path(path, paste0(strsplit(filename, '\\.')[[1]][1], '.dat'))
-      tdatFile <- file.path(path, paste0(strsplit(filename, '\\.')[[1]][1], '.tdat'))
-    } else if (format == TWO_COL) {
-      datFile <-  file.path(path, paste0(strsplit(filename, '\\.')[[1]][1], '.dat'))
+    # for an unknown suite, to detect the format
+    if (is.null(suite) || length(suite) == 0) {
+      if (verbose)
+        warning("Suite-name not provided in .info-file, taking best guess based on
+                the format of data-files.")
+      suite <- switch(format,
+                      IOHprofiler = "PBO",
+                      COCO = "BBOB",
+                      BIOBJ_COCO = "biobj-bbob",
+                      TWO_COL = NULL)
     }
 
-    # TODO: whether to keep the raw data set list?
-    if (format == IOHprofiler) {
-      dat <- read_dat(datFile, subsampling)         # read the dat file
-      cdat <- read_dat(cdatFile, subsampling)       # read the cdat file
-    } else if (format == COCO) {
-      #Should we use read_COCO_dat or read_COCO_dat2?
-      dat <- read_COCO_dat2(datFile, subsampling)    # read the dat file
-      cdat <- read_COCO_dat2(tdatFile, subsampling)   # read the tdat file
-    } else if (format == BIBOJ_COCO) {
-      dat <- read_BIOBJ_COCO_dat(datFile, subsampling)    # read the dat file
-      cdat <- read_BIOBJ_COCO_dat(tdatFile, subsampling)   # read the tdat file
-    } else if (format == TWO_COL) {
-      dat <- read_dat(datFile, subsampling)
+    if (is.null(maximization)) {
+      maximization <- info$maximization
+      if (is.null(maximization) && !is.null(suite)) {
+        if (verbose)
+          warning("maximization or minimization not specified in .info-file,
+                  taking best guess based on the suite-name.")
+        if (grepl("\\w*bbob\\w*", suite, ignore.case = T) != 0)
+          maximization <- F
+        else
+          maximization <- T
+      }
     }
 
-    # check if the number of instances does not match
-    if (format != TWO_COL)
-      stopifnot(length(dat) == length(cdat))
+    datBaseName <- strsplit(basename(info$datafile), '\\.')[[1]][1]
+    datFile <- file.path(path, paste0(datBaseName, '.dat'))
+    tdatFile <- file.path(path, paste0(datBaseName, '.tdat'))
+    cdatFile <- file.path(path, paste0(datBaseName, '.cdat'))
 
-    if (is.null(maximization)){
-      if (format == IOHprofiler || format == TWO_COL)
-        maximization <- TRUE
-      else if (format == COCO)
-        maximization <- FALSE
-    }
-    # RT <- align_by_target(dat, maximization = maximization, format = format) # runtime
-    RT <- align_runtime(dat, format = format, maximization = maximization)
-
-    #TODO: check if this works correctly without CDAT-file
-    if (format == TWO_COL)
-      FV <- align_function_value(dat, format = format)  # function value
+    # NOTE: preference on data file for the alignment by RT: cdat > tdat > dat
+    if (file.exists(cdatFile))
+      fvFile <- cdatFile
+    else if (file.exists(tdatFile))
+      fvFile <- tdatFile
+    else if (file.exists(datFile))
+      fvFile <- datFile
     else
-      FV <- align_function_value(cdat, format = format)  # function value
+      stop('No datafiles found, please verify the integrity of the chosen files')
 
-    # TODO: remove this and incorporate the parameters aligned by runtimes
-    FV[names(FV) != 'FV'] <- NULL
+    # NOTE: preference on data file for the alignment by FV: dat > tdat > cdat
+    if (file.exists(datFile))
+      rtFile <- datFile
+    else if (file.exists(tdatFile))
+      rtFile <- tdatFile
+    else if (file.exists(cdatFile))
+      # TODO: perhaps turn on `subsampling` here as this would take quite some time
+      rtFile <- cdatFile
+
+    read_raw <- switch(
+      format,
+      IOHprofiler = read_dat,
+      COCO = read_dat__COCO,
+      BIOBJ_COCO = read_dat__BIOBJ_COCO,
+      TWO_COL = read_dat
+    )
+
+    RT_raw <- read_raw(rtFile, subsampling)
+    FV_raw <- read_raw(fvFile, subsampling)
+
+    if (is.null(maximization)) {
+      if (verbose)
+        warning("Did not find maximization / minimization, auto-detecting based on
+                function value progression")
+      # TODO: idxTarget should be set depending on the data format
+      idxTarget <- 2
+      cond <- unique(lapply(FV_raw, function(FV) FV[1, idxTarget] >= FV[nrow(FV), idxTarget]))
+      if (length(cond) > 1)
+        stop('The detected maximization differs in multiple runs')
+      maximization <- cond
+    }
+
+    RT <- align_running_time(RT_raw, format = format, maximization = maximization)
+    FV <- align_function_value(FV_raw, format = format)
+
+    PAR <- list(
+      'by_FV' = RT[names(RT) != 'RT'],
+      'by_RT' = FV[names(FV) != 'FV']
+    )
+
+    RT <- RT$RT
+    FV <- FV$FV
 
     # TODO: add more data sanity checks
+    maxRT <- set_names(sapply(RT_raw, function(d) d[nrow(d), idxEvals]), NULL)
+    # Fix for old-format files which do not store used runtime in .dat-files
+    maxRT <- pmax(maxRT, info$maxRT)
+    if (any(maxRT != info$maxRT) && verbose)
+      warning('Inconsitent maxRT in *.info file and *.cdat file')
 
-    # TODO: add the same sanity checks for TWO_COL format
-    if (format != TWO_COL) {
-      maxRT <- sapply(cdat, function(d) d[nrow(d), idxEvals]) %>% set_names(NULL)
-      # if (any(maxRT != info$maxRT))
-      #   warning('Inconsitent maxRT in *.info file and *.cdat file')
-    }
-    else{
-      maxRT <- info$maxRT
-    }
-
-    #TODO: Clean up these if-statements: Function to set idxTarget and n_data_column?
+    # TODO: clean up these if-statements: Function to set idxTarget and n_data_column?
+    # `idxTarget` is a global variable?
     if (format == TWO_COL)
-      finalFV <- sapply(dat, function(d) d[nrow(d), idxTarget - 1]) %>% set_names(NULL)
+      finalFV <- set_names(sapply(FV_raw, function(d) d[nrow(d), idxTarget - 1]), NULL)
     else
-      finalFV <- sapply(dat, function(d) d[nrow(d), idxTarget]) %>% set_names(NULL)
+      finalFV <- set_names(sapply(FV_raw, function(d) d[nrow(d), idxTarget]), NULL)
 
-    # if (any(finalFV != info$finalFV))
-    #   warning('Inconsitent finalFvalue in *.info file and *.dat file')
+    if (any(finalFV != info$finalFV) && verbose)
+      warning('Inconsitent finalFvalue in *.info file and *.dat file')
 
-    if (length(info$instance) != length(dat)) {
-      warning('The number of instances found in the info is inconsistent with the data!')
-      info$instance <- seq(length(dat))
+    if (length(info$instance) != length(RT_raw)) {
+      if (verbose)
+        warning('The number of instances found in the info is inconsistent with the data!')
+      info$instance <- seq(length(RT_raw))
     }
 
-    # TODO: maybe the RT summary should not be always pre-computed
-    AUX <- list()
-    # data <- RT$RT
-    # n_instance <- length(info$instance)
-    # RT.summary <- data.table(target = rownames(data) %>% as.double,
-    #                          mean = apply(data, 1, .mean),
-    #                          median = apply(data, 1, .median),
-    #                          sd = apply(data, 1, .sd))
-    #
-    # names <- paste0(probs * 100, '%')
-    # RT.summary[, (names) := t(apply(data, 1, D_quantile)) %>% split(c(col(.)))]
-    # RT.summary[, c('ERT', 'runs', 'ps') := SP(data, maxRT)]
-    # AUX$RT.summary <- RT.summary
-
-    do.call(function(...) structure(c(RT, FV, AUX), class = c('DataSet', 'list'), ...),
-            c(info, list(maxRT = maxRT, finalFV = finalFV, format = format,
-                         maximization = maximization)))
-
-  } else {
-    structure(list(), class = c('DataSet', 'list'))
+    do.call(
+      function(...)
+        structure(list(RT = RT, FV = FV, PAR = PAR), class = c('DataSet', 'list'), ...),
+      c(info, list(maxRT = maxRT, finalFV = finalFV, format = format,
+                   maximization = maximization, suite = suite))
+    )
   }
+  else
+    structure(list(), class = c('DataSet', 'list'))
+}
+
+#' S3 concatenation function for DataSet
+#'
+#' @description Concatenation for DataSets. Combines multiple runs from separate DataSets
+#' into a single DataSet object if all provided arguments have the same dimension, function ID and
+#' algorithm ID, and each contains only a single run. Currently does not support parameter tracking
+#' 
+#' @param ... The DataSets to concatenate
+#' @return A new DataSet
+#' @export
+c.DataSet <- function(...) {
+  dsl <- list(...)
+  dsl <- dsl[sapply(dsl, length) != 0]
+  
+  if (length(dsl) == 0)
+    return()
+  
+  for (ds in dsl) {
+    if (!any((class(dsl[[1]])) == 'DataSet'))
+      stop("Operation only possible when all arguments are DataSets")
+  }
+  
+  info <- list()
+  for (attr_str in c('suite', 'maximization', 'DIM', 'funcId', 'algId')) {
+    temp  <-
+      unique(
+        unlist(lapply(dsl, function(x)
+          attr(x, attr_str))))
+    if (length(temp) > 1) {
+      stop(paste0("Attempted to add datasets with different ", attr_str, 
+                  "-attributes! Tis is not allowed, please keep them as separate DataSets!"))
+    }
+    info <- c(info,temp)
+  }
+  names(info) <- c('suite', 'maximization', 'DIM', 'funcId', 'algId')
+  
+  maxRT <- max(unlist(lapply(dsl, function(x) attr(x, "maxRT"))))
+  if (info$maximization)
+    finalFV <- max(unlist(lapply(dsl, function(x) attr(x, "finalFV"))))
+  else
+    finalFV <- min(unlist(lapply(dsl, function(x) attr(x, "finalFV"))))
+  
+  format <- attr(dsl[[1]], "format")
+  
+  RT_raw <- c()
+  #Note: Currently only works for data split in a way that there is one run per DataSet
+  #TODO: Generalize to more runs -> detection + dealing with it
+  for (i in seq(length(dsl))) {
+    rt_temp <- as.matrix(dsl[[i]]$RT)
+    rt_temp <- cbind(rt_temp, as.numeric(rownames(dsl[[i]]$RT)))
+    RT_raw[[i]] <- rt_temp
+  }
+  
+  RT <- align_running_time(RT_raw, format = "TWO_COL", maximization = info$maximization)
+  FV <- align_function_value(RT_raw, format = "TWO_COL")
+  
+  #TODO: Deal with cases where parameters are present in original DataSets
+  PAR <- list(
+    'by_FV' = RT[names(RT) != 'RT'],
+    'by_RT' = FV[names(FV) != 'FV']
+  )
+  
+  do.call(
+    function(...)
+      structure(list(RT = RT, FV = FV, PAR = PAR), class = c('DataSet', 'list'), ...),
+    c(info, list(maxRT = maxRT, finalFV = finalFV, format = format))
+  )
 }
 
 #' S3 generic print operator for DataSet
 #'
 #' @param x A DataSet object
-#' @param verbose Verbose mode, currently not implemented
 #' @param ... Arguments passed to other methods
 #'
 #' @return A short description of the DataSet
-#' @examples 
+#' @examples
 #' print(dsl[[1]])
 #' @export
-print.DataSet <- function(x, verbose = F, ...) {
-  # TODO: implement the verbose mode
+print.DataSet <- function(x, ...) {
   cat(as.character.DataSet(x, ...))
 }
 
@@ -159,7 +234,7 @@ print.DataSet <- function(x, verbose = F, ...) {
 #'
 #' @return A short description of the DataSet
 #' @export
-#' @examples 
+#' @examples
 #' cat.DataSet(dsl[[1]])
 cat.DataSet <- function(x) cat(as.character(x))
 
@@ -171,7 +246,7 @@ cat.DataSet <- function(x) cat(as.character(x))
 #'
 #' @return A short description of the DataSet
 #' @export
-#' @examples 
+#' @examples
 #' as.character(dsl[[1]])
 as.character.DataSet <- function(x, verbose = F, ...) {
   # TODO: implement the verbose mode
@@ -185,7 +260,7 @@ as.character.DataSet <- function(x, verbose = F, ...) {
 #' @param ... Arguments passed to other methods
 #'
 #' @return A summary of the DataSet containing both function-value and runtime based statistics.
-#' @examples 
+#' @examples
 #' summary(dsl[[1]])
 #' @export
 summary.DataSet <- function(object, ...) {
@@ -207,13 +282,13 @@ summary.DataSet <- function(object, ...) {
     cat(sprintf('%d instance found: %s\n\n', n_instance, paste(ds_attr$instance, collapse = ',')))
 
   cat('runtime summary:\n')
-  function_values <- rownames(object$RT) %>% as.numeric
+  function_values <- as.numeric(rownames(object$RT))
   RT.summary <- get_RT_summary(object, function_values)
   print(RT.summary)
   cat('\n')
 
   cat('function value summary:\n')
-  runtimes <- rownames(object$FV) %>% as.numeric
+  runtimes <- as.numeric(rownames(object$FV))
   if (length(runtimes) > 100) {
     runtimes <- runtimes[seq(1, length(runtimes), length.out = 100)]
   }
@@ -227,13 +302,13 @@ summary.DataSet <- function(object, ...) {
 
 #' S3 generic == operator for DataSets
 #'
-#' @param dsL A DataSet object
-#' @param dsR A DataSet object
+#' @param dsL A `DataSet` object
+#' @param dsR A `DataSet` object
 #'
 #'
 #' @return True if the DataSets contain the same function, dimension and algorithm,
 #' and have equal precision and comments; False otherwise
-#' @examples 
+#' @examples
 #' dsl[[1]] == dsl[[2]]
 #' @export
 `==.DataSet` <- function(dsL, dsR) {
@@ -255,12 +330,13 @@ summary.DataSet <- function(object, ...) {
 #'
 #' @return A data.table containing the runtime samples for each provided target
 #' function value
-#' @examples 
+#' @examples
 #' get_ERT(dsl, 14)
 #' get_ERT(dsl[[1]], 14)
 #' @export
 #'
 get_ERT <- function(ds, ftarget, ...) UseMethod("get_ERT", ds)
+
 #' Get RunTime Sample
 #'
 #' @param ds A DataSet or DataSetList object
@@ -270,24 +346,26 @@ get_ERT <- function(ds, ftarget, ...) UseMethod("get_ERT", ds)
 #'
 #' @return A data.table containing the runtime samples for each provided target
 #' function value
-#' @examples 
+#' @examples
 #' get_RT_sample(dsl, 14)
 #' get_RT_sample(dsl[[1]], 14)
 #' @export
 get_RT_sample <- function(ds, ftarget, ...) UseMethod("get_RT_sample", ds)
+
 #' Get RunTime Summary
 #'
 #' @param ds A DataSet or DataSetList object
 #' @param ... Arguments passed to other methods
 #' @param ftarget The function target(s) for which to get the runtime summary
-#' 
+#'
 #' @return A data.table containing the runtime statistics for each provided target
 #' function value
-#' @examples 
+#' @examples
 #' get_RT_summary(dsl, 14)
 #' get_RT_summary(dsl[[1]], 14)
 #' @export
 get_RT_summary <- function(ds, ftarget, ...) UseMethod("get_RT_summary", ds)
+
 #' Get Funtion Value Samples
 #'
 #' @param ds A DataSet or DataSetList object
@@ -296,11 +374,12 @@ get_RT_summary <- function(ds, ftarget, ...) UseMethod("get_RT_summary", ds)
 #'
 #' @return A data.table containing the function value samples for each provided
 #' target runtime
-#' @examples 
+#' @examples
 #' get_FV_sample(dsl, 100)
 #' get_FV_sample(dsl[[1]], 100)
 #' @export
 get_FV_sample <- function(ds, ...) UseMethod("get_FV_sample", ds)
+
 #' Get Function Value Summary
 #'
 #' @param ds A DataSet or DataSetList object
@@ -309,58 +388,68 @@ get_FV_sample <- function(ds, ...) UseMethod("get_FV_sample", ds)
 #'
 #' @return A data.table containing the function value statistics for each provided
 #' target runtime value
-#' @examples 
+#' @examples
 #' get_FV_summary(dsl, 100)
 #' get_FV_summary(dsl[[1]], 100)
 #' @export
 get_FV_summary <- function(ds, ...) UseMethod("get_FV_summary", ds)
+
 #' Get Parameter Value Samples
 #'
 #' @param ds A DataSet or DataSetList object
-#' @param ftarget A Numerical vector. Function values at which parameter values are observed
+#' @param idxValue A Numerical vector. Index values at which parameter values are observed.
+#' The index value can either take its value in the range of running times, or function values.
+#' Such a value type is signified by `which` parameter.
 #' @param ... Arguments passed to other methods
-#' 
+#'
 #' @return A data.table object containing parameter values aligned at each given target value
-#' @examples 
+#' @examples
 #' get_PAR_sample(dsl, 14)
 #' get_PAR_sample(dsl[[1]], 14)
 #' @export
-get_PAR_sample <- function(ds, ftarget, ...) UseMethod("get_PAR_sample", ds)
+get_PAR_sample <- function(ds, idxValue, ...) UseMethod("get_PAR_sample", ds)
+
 #' Get Parameter Value Summary
 #'
 #' @param ds A DataSet or DataSetList object
-#' @param ftarget A Numerical vector. Function values at which parameter values are observed
+#' @param idxValue A Numerical vector. Index values at which parameter values are observed.
+#' The index value can either take its value in the range of running times, or function values.
+#' Such a value type is signified by `which` parameter.
 #' @param ... Arguments passed to other methods
 #'
 #' @return A data.table object containing basic statistics of parameter values aligned at each given target value
-#' @examples 
+#' @examples
 #' get_PAR_summary(dsl, 14)
 #' get_PAR_summary(dsl[[1]], 14)
 #' @export
-get_PAR_summary <- function(ds, ftarget, ...) UseMethod("get_PAR_summary", ds)
+get_PAR_summary <- function(ds, idxValue, ...) UseMethod("get_PAR_summary", ds)
 
 #' Get the parameter names of the algorithm
 #'
 #' @param ds A DataSet object
-#'
+#' @param which a string takes it value in `c('by_FV', 'by_RT')`, indicating the
+#' parameters aligned against the running time (RT) or function value (FV). `'by_FV'`
+#' is the default value.
 #' @return a character list of paramter names, if recorded in the data set
-#' @examples 
+#' @examples
 #' get_PAR_name(dsl[[1]])
 #' @export
-get_PAR_name <- function(ds) UseMethod("get_PAR_name", ds)
+get_PAR_name <- function(ds, which) UseMethod("get_PAR_name", ds)
+
 #' Get Function Value condensed overview
 #'
-#' @param ds A DataSet or DataSetList object
+#' @param ds A `DataSet` or `DataSetList` object
 #' @param ... Arguments passed to other methods
 #'
 #' @return A data.table containing the algorithm ID, best, worst and mean reached function
 #' values, the number of runs and available budget for the DataSet
-#' @examples 
+#' @examples
 #' get_FV_overview(dsl)
 #' get_FV_overview(dsl[[1]])
-#' get_FV_overview(dsl, algorithm = "(1+1)_greedy_hill_climber_1" )
+#' get_FV_overview(dsl, algorithm = '(1+1)_greedy_hill_climber_1')
 #' @export
 get_FV_overview <- function(ds, ...) UseMethod("get_FV_overview", ds)
+
 #' Get Runtime Value condensed overview
 #'
 #' @param ds A DataSet or DataSetList object
@@ -368,12 +457,23 @@ get_FV_overview <- function(ds, ...) UseMethod("get_FV_overview", ds)
 #'
 #' @return A data.table containing the algorithm ID, minimum and maximum used evaluations,
 #' number of runs and available budget for the DataSet
-#' @examples 
+#' @examples
 #' get_RT_overview(dsl)
 #' get_RT_overview(dsl[[1]])
 #' @export
 get_RT_overview <- function(ds, ...) UseMethod("get_RT_overview", ds)
 
+#' Get condensed overview of datasets
+#'
+#' @param ds A DataSet or DataSetList object
+#' @param ... Arguments passed to other methods
+#'
+#' @return A data.table containing some basic information about the provided DataSet(List)
+#' @examples
+#' get_overview(dsl)
+#' get_overview(dsl[[1]])
+#' @export
+get_overview <- function(ds, ...) UseMethod("get_overview", ds)
 
 #' @rdname get_FV_overview
 #' @export
@@ -411,15 +511,15 @@ get_FV_overview.DataSet <- function(ds, ...) {
 #' @export
 #'
 get_RT_overview.DataSet <- function(ds, ...) {
-  
-  if(!is.null(attr(ds, "format")) && attr(ds, "format") == NEVERGRAD){
+
+  if (!is.null(attr(ds, "format")) && attr(ds, "format") == NEVERGRAD) {
     data <- ds$FV
     budget <- max(attr(ds, 'maxRT'))
     runs <- ncol(data)
     min_rt <- rownames(data) %>% as.integer %>% min
     max_rt <- budget
   }
-  
+
   else{
     data <- ds$RT
     runs <- ncol(data)
@@ -427,14 +527,57 @@ get_RT_overview.DataSet <- function(ds, ...) {
     min_rt <- min(data, na.rm = T)
     max_rt <- max(data, na.rm = T)
   }
-  
+
   data.table(algId = attr(ds, 'algId'),
              DIM = attr(ds, 'DIM'),
              funcId = attr(ds, 'funcId'),
              `miminal runtime` = min_rt,
              `maximal runtime` = max_rt,
-             'runs' = runs,
-             Budget = budget)
+             `runs` = runs,
+             `Budget` = budget)
+}
+
+#' @rdname get_overview
+#' @export
+#'
+get_overview.DataSet <- function(ds, ...) {
+  data <- ds$FV
+  runs <- ncol(data)
+
+  budget <- max(attr(ds, 'maxRT'))
+  if (!is.null(ds$RT) && length(ds$RT) > 0) {
+    max_rt <- max(ds$RT, na.rm = T)
+    budget <- max(budget, max_rt)
+  }
+  else max_rt <- budget
+
+  last_row <- data[nrow(data), ]
+  maximization <- attr(ds, 'maximization')
+
+  op <- ifelse(maximization, max, min)
+  op_inv <- ifelse(maximization, min, max)
+
+  best_fv <- op(last_row, na.rm = T)
+  worst_recorded_fv <- op_inv(data, na.rm = T)
+  worst_fv <- op_inv(last_row, na.rm = T)
+  mean_fv <- mean(last_row, na.rm = T)
+  median_fv <- median(last_row, na.rm = T)
+  runs_reached <- sum(last_row == best_fv)
+
+  data.table(`algId` = attr(ds, 'algId'),
+             `DIM` = attr(ds, 'DIM'),
+             `funcId` = attr(ds, 'funcId'),
+             `runs` = runs,
+             `best reached` = best_fv,
+             `succ` = runs_reached,
+             `budget` = budget,
+             `max evals used` = max_rt,
+             `worst recorded` = worst_recorded_fv,
+             `worst reached` = worst_fv,
+             `mean reached` = mean_fv,
+             `median reached` = median_fv
+  )
+
 }
 
 #' @rdname get_ERT
@@ -446,28 +589,20 @@ get_ERT.DataSet <- function(ds, ftarget, ...) {
   algId <- attr(ds, 'algId')
   maximization <- attr(ds, 'maximization')
 
-  ftarget <- c(ftarget) %>% as.double %>% sort(decreasing = !maximization)
-  FValues <- rownames(data) %>% as.numeric
+  ftarget <- sort(as.double(unique(c(ftarget))), decreasing = !maximization)
+  FValues <- as.numeric(rownames(data))
   idx <- seq_along(FValues)
   op <- ifelse(maximization, `>=`, `<=`)
 
-  matched <- sapply(
-    ftarget,
-    function(f) {
-      idx[`op`(FValues, f)][1]
-    }
-  )
+  matched <- sapply(ftarget, function(f) idx[`op`(FValues, f)][1])
 
-  if (is.list(matched)) {
+  if (is.list(matched))
     return(data.table())
-  }
 
   data <- data[matched, , drop = FALSE]
-
-  SP(data, maxRT)$ERT %>%
-  cbind(algId, ftarget, .) %>%
-    as.data.table %>%
-    set_colnames(c('algId', 'target', 'ERT'))
+  dt <- as.data.table(cbind(algId, ftarget, SP(data, maxRT)$ERT))
+  colnames(dt) <- c('algId', 'target', 'ERT')
+  dt
 }
 
 #' @rdname get_RT_summary
@@ -479,8 +614,8 @@ get_RT_summary.DataSet <- function(ds, ftarget, ...) {
   algId <- attr(ds, 'algId')
   maximization <- attr(ds, 'maximization')
 
-  ftarget <- c(ftarget) %>% as.double %>% sort(decreasing = !maximization)
-  FValues <- rownames(data) %>% as.numeric
+  ftarget <- sort(as.double(unique(c(ftarget))), decreasing = !maximization)
+  FValues <- as.numeric(rownames(data))
   idx <- seq_along(FValues)
   op <- ifelse(maximization, `>=`, `<=`)
 
@@ -495,14 +630,6 @@ get_RT_summary.DataSet <- function(ds, ftarget, ...) {
     return(data.table())
   }
 
-  # func <- lapply(func,
-  #   function(f)
-  #     switch(f,
-  #       mean = .mean, median = .median, sd = .sd,
-  #       quantile = D_quantile, ERT = SP
-  #     )
-  # )
-
   if (1 < 2) {
     data <- data[matched, , drop = FALSE]
     apply(data, 1, IOHanalyzer_env$D_quantile) %>%
@@ -514,7 +641,8 @@ get_RT_summary.DataSet <- function(ds, ftarget, ...) {
             apply(data, 1, .median),
             apply(data, 1, .sd), .) %>%
       set_colnames(c('algId', 'target', 'mean', 'median',
-                     'sd', paste0(getOption("IOHanalyzer.quantiles") * 100, '%'), 'ERT', 'runs', 'ps'))
+                     'sd', paste0(getOption("IOHanalyzer.quantiles") * 100, '%'),
+                     'ERT', 'runs', 'ps'))
   } else {# TODO: remove this case, deprecated...
     NAs <- is.na(matched)
     if (any(NAs)) {
@@ -530,6 +658,39 @@ get_RT_summary.DataSet <- function(ds, ftarget, ...) {
   }
 }
 
+#' Get the maximal running time
+#'
+#' @param ds A DataSet or DataSetList object
+#' @param ... Arguments passed to other methods
+#'
+#' @return A data.table object containing the algorithm ID and the running time
+#' when the algorithm terminates in each run
+#' @examples
+#' get_maxRT(dsl)
+#' get_maxRT(dsl[[1]])
+#' @export
+get_maxRT <- function(ds, ...) UseMethod("get_maxRT", ds)
+
+#' @rdname get_maxRT
+#' @param output The format of the outputted table: 'wide' or 'long'
+#' @export
+#'
+get_maxRT.DataSet <- function(ds, output = 'wide', ...) {
+  algId <- attr(ds, 'algId')
+  N <- ncol(ds$RT)
+  res <- t(c(algId, attr(ds, 'maxRT'))) %>%
+    as.data.table %>%
+    set_colnames(c('algId', paste0('run.', seq(N))))
+
+  if (output == 'long') {
+    res <- melt(res, id = 'algId', variable.name = 'run', value.name = 'maxRT')
+    res[, run := as.numeric(gsub('run.', '', run)) %>% as.integer
+        ][, maxRT := as.integer(maxRT)
+          ][order(run)]
+  }
+  res
+}
+
 #' @rdname get_RT_sample
 #' @param output A character determining the format of output data.table: 'wide' or 'long'
 #' @export
@@ -539,8 +700,8 @@ get_RT_sample.DataSet <- function(ds, ftarget, output = 'wide', ...) {
   algId <- attr(ds, 'algId')
   maximization <- attr(ds, 'maximization')
 
-  ftarget <- c(ftarget) %>% unique %>% as.double %>% sort(decreasing = !maximization)
-  FValues <- rownames(data) %>% as.double
+  ftarget <- sort(as.double(unique(c(ftarget))), decreasing = !maximization)
+  FValues <- as.double(rownames(data))
   idx <- seq_along(FValues)
   op <- ifelse(maximization, `>=`, `<=`)
 
@@ -551,15 +712,13 @@ get_RT_sample.DataSet <- function(ds, ftarget, output = 'wide', ...) {
     }
   )
 
-  res <- data[matched, , drop = FALSE] %>%
-    as.data.table %>%
-    cbind(algId, ftarget, .) %>%
+  res <- cbind(algId, ftarget, as.data.table(data[matched, , drop = FALSE])) %>%
     set_colnames(c('algId', 'target', paste0('run.', seq(N))))
 
   if (output == 'long') {
     #TODO: option to not add runnr etc to speed up performance of ECDF calculation?
     res <- melt(res, id = c('algId', 'target'), variable.name = 'run', value.name = 'RT')
-    res[, run := as.numeric(gsub('run.', '', run)) %>% as.integer
+    res[, run := as.integer(as.numeric(gsub('run.', '', run)))
         ][, RT := as.integer(RT)
           ][order(target, run)]
   }
@@ -576,8 +735,8 @@ get_FV_summary.DataSet <- function(ds, runtime, ...) {
   algId <- attr(ds, 'algId')
   maximization <- attr(ds, 'maximization')
 
-  runtime <- c(runtime) %>% unique %>% as.numeric %>% sort
-  RT <- rownames(data) %>% as.numeric
+  runtime <- sort(as.numeric(unique(c(runtime))))
+  RT <- as.numeric(rownames(data))
   idx <- seq_along(RT)
 
   matched <- sapply(runtime, function(r) {
@@ -586,14 +745,15 @@ get_FV_summary.DataSet <- function(ds, runtime, ...) {
   })
 
   data <- data[matched, , drop = FALSE]
-  apply(data, 1, IOHanalyzer_env$C_quantile) %>%
-    t %>%
-    as.data.table %>%
-    cbind(algId, runtime, NC,
-          apply(data, 1, .mean),
-          apply(data, 1, .median),
-          apply(data, 1, .sd), .) %>%
-    set_colnames(c('algId', 'runtime', 'runs', 'mean', 'median', 'sd', paste0(getOption("IOHanalyzer.quantiles") * 100, '%')))
+  df <- cbind(algId, runtime, NC,
+              apply(data, 1, .mean),
+              apply(data, 1, .median),
+              apply(data, 1, .sd),
+              as.data.table(t(apply(data, 1, IOHanalyzer_env$C_quantile)))
+  )
+  colnames(df) <- c('algId', 'runtime', 'runs', 'mean', 'median', 'sd',
+                    paste0(getOption("IOHanalyzer.quantiles") * 100, '%'))
+  df
 }
 
 #' @rdname get_FV_sample
@@ -608,8 +768,8 @@ get_FV_sample.DataSet <- function(ds, runtime, output = 'wide', ...) {
   algId <- attr(ds, 'algId')
   maximization <- attr(ds, 'maximization')
 
-  runtime <- c(runtime) %>% unique %>% as.numeric %>% sort
-  RT <- rownames(data) %>% as.numeric
+  runtime <- sort(as.numeric(unique(c(runtime))))
+  RT <- as.numeric(rownames(data))
   idx <- seq_along(RT)
 
   matched <- sapply(runtime, function(r) {
@@ -617,14 +777,12 @@ get_FV_sample.DataSet <- function(ds, runtime, output = 'wide', ...) {
     ifelse(is.na(res), n_row, res)
   })
 
-  res <- data[matched, , drop = FALSE] %>%
-    as.data.table %>%
-    cbind(algId, runtime, .) %>%
+  res <- cbind(algId, runtime, as.data.table(data[matched, , drop = FALSE])) %>%
     set_colnames(c('algId', 'runtime', paste0('run.', seq(N))))
 
   if (output == 'long') {
     res <- melt(res, id = c('algId', 'runtime'), variable.name = 'run', value.name = 'f(x)')
-    res[, run := as.numeric(gsub('run.', '', run)) %>% as.integer
+    res[, run := as.integer(as.numeric(gsub('run.', '', run)))
         ][order(runtime, run)]
   }
   res
@@ -633,94 +791,120 @@ get_FV_sample.DataSet <- function(ds, runtime, output = 'wide', ...) {
 #' @rdname get_PAR_name
 #' @export
 #'
-get_PAR_name.DataSet <- function(ds) {
-  name <- names(ds)
-  name[!(name %in% c('RT', 'RT.summary', 'FV'))]
+get_PAR_name.DataSet <- function(ds, which = 'by_FV') {
+  names(ds$PAR[[which]])
 }
 
 #' @rdname get_PAR_summary
 #' @param parId A character vector. Either 'all' or the name of parameters to be retrieved
+#' @param which A string takes values in `c('by_FV', 'by_RT')`, indicating the parameters to be
+#' retrieved are aligned against the running time (RT) or function value (FV). `'by_FV'`
+#' is the default value.
 #' @export
-get_PAR_summary.DataSet <- function(ds, ftarget, parId = 'all', ...) {
-  FValues <- rownames(ds$RT) %>% as.numeric
-  idx <- seq_along(FValues)
+get_PAR_summary.DataSet <- function(ds, idxValue, parId = 'all', which = 'by_FV', ...) {
+  if (which == 'by_FV') {
+    RefValues <- as.numeric(rownames(ds$RT))
+    ds_par <- ds$PAR$by_FV
+    idx_name <- 'target'
+  }
+  else if (which == 'by_RT') {
+    RefValues <- as.numeric(rownames(ds$FV))
+    ds_par <- ds$PAR$by_RT
+    idx_name <- 'runtime'
+  }
 
+  idx <- seq_along(RefValues)
   algId <- attr(ds, 'algId')
-  par_name <- get_PAR_name(ds)
+  par_name <- get_PAR_name(ds, which = which)
+
   if (parId != 'all')
     par_name <- intersect(par_name, parId)
   if (length(par_name) == 0)
     return(NULL)
 
   maximization <- attr(ds, 'maximization')
-  ftarget <- c(ftarget) %>% as.numeric %>% sort(decreasing = !maximization)
-  op <- ifelse(maximization, `>=`, `<=`)
+  cond <- maximization || which == 'by_RT'
+  op <- ifelse(cond, `>=`, `<=`)
+  idxValue <- sort(as.numeric(c(idxValue)), decreasing = !cond)
 
   matched <- sapply(
-    ftarget,
+    idxValue,
     function(f) {
-      idx[`op`(FValues, f)][1]
+      idx[`op`(RefValues, f)][1]
     }
   )
 
   lapply(par_name,
          function(par) {
-           data <- ds[[par]][matched, , drop = FALSE]
-           apply(data, 1, IOHanalyzer_env$C_quantile) %>%
-             t %>%
-             as.data.table %>%
-             cbind(algId, par, ftarget,
-                   apply(data, 1, function(x) length(x[!is.na(x)])),
-                   apply(data, 1, .mean),
-                   apply(data, 1, .median),
-                   apply(data, 1, .sd), .) %>%
-             set_colnames(c('algId', 'parId', 'target', 'runs', 'mean', 'median', 'sd',
-                            paste0(getOption("IOHanalyzer.quantiles") * 100, '%')))
+           data <- ds_par[[par]][matched, , drop = FALSE]
+           df <- cbind(
+             algId, par, idxValue,
+             apply(data, 1, function(x) length(x[!is.na(x)])),
+             apply(data, 1, .mean),
+             apply(data, 1, .median),
+             apply(data, 1, .sd),
+             as.data.table(t(apply(data, 1, IOHanalyzer_env$C_quantile)))
+           )
+           colnames(df) <- c('algId', 'parId', idx_name, 'runs', 'mean', 'median', 'sd',
+                             paste0(getOption("IOHanalyzer.quantiles") * 100, '%'))
+           df
          }) %>%
     rbindlist
 }
 
 #' @rdname get_PAR_sample
 #' @param parId A character vector. Either 'all' or the name of parameters to be retrieved
+#' @param which A string takes values in `c('by_FV', 'by_RT')`, indicating the parameters to be
+#' retrieved are aligned against the running time (RT) or function value (FV). `'by_FV'`
+#' is the default value.
 #' @param output A character. The format of the output data: 'wide' or 'long'
 #' @export
-get_PAR_sample.DataSet <- function(ds, ftarget, parId = 'all', output = 'wide', ...) {
+get_PAR_sample.DataSet <- function(ds, idxValue, parId = 'all', which = 'by_FV',
+                                   output = 'wide', ...) {
   N <- length(attr(ds, 'instance'))
-  FValues <- rownames(ds$RT) %>% as.numeric
-  idx <- seq_along(FValues)
+  if (which == 'by_FV') {
+    RefValues <- as.numeric(rownames(ds$RT))
+    ds_par <- ds$PAR$by_FV
+    idx_name <- 'target'
+  }
+  else if (which == 'by_RT') {
+    RefValues <- as.numeric(rownames(ds$FV))
+    ds_par <- ds$PAR$by_RT
+    idx_name <- 'runtime'
+  }
 
+  idx <- seq_along(RefValues)
   algId <- attr(ds, 'algId')
-  par_name <- get_PAR_name(ds)
+  par_name <- get_PAR_name(ds, which = which)
+
   if (parId != 'all')
     par_name <- intersect(par_name, parId)
   if (length(par_name) == 0)
     return(NULL)
 
   maximization <- attr(ds, 'maximization')
-  ftarget <- c(ftarget) %>% as.numeric %>% sort(decreasing = !maximization)
-  op <- ifelse(maximization, `>=`, `<=`)
-
-  matched <- sapply(
-    ftarget,
-    function(f) {
-      idx[`op`(FValues, f)][1]
-    }
-  )
+  cond <- maximization || which == 'by_RT'
+  op <- ifelse(cond, `>=`, `<=`)
+  idxValue <- sort(as.numeric(c(idxValue)), decreasing = !cond)
+  matched <- sapply(idxValue, function(f) idx[`op`(RefValues, f)][1])
 
   res <- lapply(par_name,
                 function(parId) {
-                  data <- ds[[parId]]
-                  data[matched, , drop = FALSE] %>%
-                    as.data.table %>%
-                    cbind(algId, parId, ftarget, .) %>%
-                    set_colnames(c('algId', 'parId', 'target', paste0('run.', seq(N))))
-                }) %>%
-    rbindlist
+                  data <- ds_par[[parId]]
+                  data <- as.data.table(data[matched, , drop = FALSE])
+                  data <- cbind(algId, parId, idxValue, data)
+                  colnames(data) <- c('algId', 'parId', idx_name, paste0('run.', seq(N)))
+                  data
+                })
+  res <- rbindlist(res)
 
   if (output == 'long') {
-    res <- melt(res, id = c('algId', 'parId', 'target'), variable.name = 'run', value.name = 'value')
-    res[, run := as.numeric(gsub('run.', '', run)) %>% as.integer
-        ][order(target, run)]
+    res <- melt(res, id = c('algId', 'parId', idx_name), variable.name = 'run', value.name = 'value')
+    res[, run := as.integer(as.numeric(gsub('run.', '', run)))]
+    if (which == 'by_FV')
+      res[order(target, run)]
+    else if (which == 'by_RT')
+      res[order(runtime, run)]
   }
   res
 }
