@@ -1,4 +1,4 @@
-#' @importFrom stats dt ecdf integrate median quantile sd 
+#' @importFrom stats dt ecdf integrate median quantile sd rgeom ks.test p.adjust
 #' @importFrom grDevices col2rgb colors nclass.FD
 #' @importFrom graphics hist
 #' @importFrom utils data head read.csv tail
@@ -7,7 +7,7 @@
 #' @importFrom colorspace sequential_hcl
 #' @importFrom RColorBrewer brewer.pal
 #' @importFrom colorRamps primary.colors
-#' @importFrom data.table as.data.table rbindlist data.table fread := melt is.data.table
+#' @importFrom data.table as.data.table rbindlist data.table fread := melt is.data.table setorderv
 #' @importFrom plotly add_annotations add_trace orca plot_ly rename_ subplot layout
 #' @importFrom ggplot2 aes geom_jitter geom_line geom_ribbon geom_violin ggplot element_text
 #' @importFrom ggplot2 guides scale_color_manual scale_colour_manual scale_fill_manual
@@ -15,14 +15,17 @@
 #' @importFrom shiny req
 #' @importFrom Rcpp sourceCpp
 #' @importFrom withr with_dir
+#' @importFrom igraph graph_from_adjacency_matrix layout.circle plot.igraph 
+#' @importFrom scales rescale
+#' @importFrom PlayerRatings glicko2
 #' @useDynLib IOHanalyzer
 NULL
-#Ugly hack, but appears to be required to appease CRAN
+# Ugly hack, but appears to be required to appease CRAN
 utils::globalVariables(c(".", "algId", "run", "ERT", "RT", "group",
                          "DIM", "Fvalue", "lower", "upper", "target", "format",
                          "runtime", "parId", "instance", "input", "funcId",
                          "budget", "dimension", "loss", "name", "optimizer_name",
-                         "rescale"))
+                         "rescale", "maxRT", "algnames", ".SD"))
 
 options(shiny.port = 4242)
 
@@ -32,16 +35,17 @@ options(shiny.port = 4242)
     IOHanalyzer.quantiles = c(2, 5, 10, 25, 50, 75, 90, 95, 98) / 100.,
     IOHanalyzer.max_samples = 100,
     IOHanalyzer.backend = 'plotly',
-    IOHanalyzer.bgcolor = 'rgb(229,229,229)',
+    IOHanalyzer.bgcolor = 'rgb(230,230,230)',
     IOHanalyzer.gridcolor = 'rgb(255,255,255)',
-    IOHanalyzer.tickcolor = 'rgb(127,127,127)',
-    IOHanalyzer.figure_width = NULL,
-    IOHanalyzer.figure_height = NULL,
-    IOHanalyzer.legend_location = 'outside_right',
+    IOHanalyzer.tickcolor = 'rgb(51,51,51)',
+    IOHanalyzer.figure_width = 1000,
+    IOHanalyzer.figure_height = 1000,
+    IOHanalyzer.legend_location = 'below',
     IOHanalyzer.legend_fontsize = 13,
     IOHanalyzer.label_fontsize = 16,
     IOHanalyzer.title_fontsize = 16,
-    IOHanalyzer.tick_fontsize = 16
+    IOHanalyzer.tick_fontsize = 12,
+    IOHanalyzer.max_colors = 2 #Set to 2 since colorbrewer only works with >= 3 colors
   )
   toset <- !(names(op.IOHanalyzer) %in% names(op))
   if (any(toset)) options(op.IOHanalyzer[toset])
@@ -49,7 +53,6 @@ options(shiny.port = 4242)
   invisible()
 }
 
-
 IOHanalyzer_env <- new.env(parent = emptyenv())
 
 .mean <- function(x) mean(x, na.rm = T)
@@ -57,13 +60,24 @@ IOHanalyzer_env <- new.env(parent = emptyenv())
 .sd <- function(x) sd(x, na.rm = T)
 .sum <- function(x) sum(x, na.rm = T)
 
-IOHanalyzer_env$D_quantile <- function(x, pct = NULL){
+# Quantile function for discrete values
+IOHanalyzer_env$D_quantile <- function(x, pct = NULL) {
   if (is.null(pct)) pct <- getOption("IOHanalyzer.quantiles")
-  quantile(x, pct, names = F, type = 3, na.rm = T)
+  tryCatch(
+    quantile(x, pct, names = F, type = 3, na.rm = T),
+    error = function(e) rep(NA, length(pct)),
+    warning = function(w) rep(NA, length(pct))
+  )
 }
-IOHanalyzer_env$C_quantile <- function(x, pct = NULL){
+
+# Quantile function for real values
+IOHanalyzer_env$C_quantile <- function(x, pct = NULL) {
   if (is.null(pct)) pct <- getOption("IOHanalyzer.quantiles")
-  quantile(x, pct, names = F, na.rm = T)
+  tryCatch(
+    quantile(x, pct, names = F, na.rm = T),
+    error = function(e) rep(NA, length(pct)),
+    warning = function(w) rep(NA, length(pct))
+  )
 }
 
 IOHprofiler <- 'IOHprofiler'
@@ -103,4 +117,4 @@ NEVERGRAD <- 'NEVERGRAD'
 #' \donttest{
 #' runServer()
 #' }
-NULL
+NULL
\ No newline at end of file
