@@ -13,25 +13,24 @@ f2 <- list(
 )
 
 # font No. 3...
-f3 <- function() {
-  list(
+f3 <- list(
     family = 'Old Standard TT, serif',
     size = getOption("IOHanalyzer.tick_fontsize", default = 16), 
     color = 'black'
-  )
-}
+)
 
-legend_right <- function(){
-  list(x = 1.01, y = 0.9, orientation = 'v',
-       font = list(size = getOption("IOHanalyzer.legend_fontsize", default = 16), 
+
+legend_right <- function() {
+  list(x = 1.01, y = 1, orientation = 'v',
+       font = list(size = getOption("IOHanalyzer.legend_fontsize", default = 18), 
                    family = 'Old Standard TT, serif'))
 }
 
-legend_inside <- function () {
+legend_inside <- function() {
   list(x = .01, y = 1, orientation = 'v',
-       bgcolor = 'rgba(255, 255, 255, 0.5)',
-       bordercolor = 'rgba(255, 255, 255, 0.8)',
-       font = list(size = getOption("IOHanalyzer.legend_fontsize", default = 16), 
+       bgcolor = 'rgba(255, 255, 255, 0)',
+       bordercolor = 'rgba(255, 255, 255, 0)',
+       font = list(size = getOption("IOHanalyzer.legend_fontsize", default = 18), 
                    family = 'Old Standard TT, serif'))
 }
 
@@ -39,23 +38,24 @@ legend_inside2 <- function() {
   list(x = 0.7, y = 0.1, orientation = 'v',
        bgcolor = 'rgba(255, 255, 255, 0.5)',
        bordercolor = 'rgba(255, 255, 255, 0.8)',
-       font = list(size = getOption("IOHanalyzer.legend_fontsize", default = 16), 
+       font = list(size = getOption("IOHanalyzer.legend_fontsize", default = 18), 
                   family = 'Old Standard TT, serif'))
 }
 
 legend_below <- function() { 
-  list(orientation = 'h',
-       font = list(size = getOption("IOHanalyzer.legend_fontsize", default = 16), 
+  list(y = -0.2, orientation = 'h',
+       font = list(size = getOption("IOHanalyzer.legend_fontsize", default = 18), 
                    family = 'Old Standard TT, serif'))
 }
 
 legend_location <- function(){
-  opt <- getOption('IOHanalyzer.legend_location', default = 'outside_right')
+  opt <- getOption('IOHanalyzer.legend_location', default = 'below')
   if (opt == 'outside_right') return(legend_right())
   else if (opt == 'inside_left') return(legend_inside())
   else if (opt == 'inside_right') return(legend_inside2())
   else if (opt == 'below') return(legend_below())
-  else warning("The selected legend option is not implemented")
+  # else if (opt == 'below2') return(legend_below2())
+  else warning(paste0("The selected legend option (", opt, ") is not implemented"))
 }
 
 # TODO: create font object as above for title, axis...
@@ -92,8 +92,8 @@ IOH_plot_ly_default <- function(title = NULL, x.title = NULL, y.title = NULL) {
                         tickcolor = getOption('IOHanalyzer.tickcolor'),
                         ticks = 'outside',
                         ticklen = 9,
-                        tickfont = f3(),
-                        exponentformat = 'E',
+                        tickfont = f3,
+                        exponentformat = 'e',
                         zeroline = F),
            yaxis = list(
                         # title = list(text = y.title, font = f3),
@@ -105,8 +105,8 @@ IOH_plot_ly_default <- function(title = NULL, x.title = NULL, y.title = NULL) {
                         tickcolor = getOption('IOHanalyzer.tickcolor'),
                         ticks = 'outside',
                         ticklen = 9,
-                        tickfont = f3(),
-                        exponentformat = 'E',
+                        tickfont = f3,
+                        exponentformat = 'e',
                         zeroline = F))
 }
 
@@ -168,6 +168,7 @@ Set3 <- function(n) colorspace::sequential_hcl(n, c(-88, 59), c. = c(60, 75, 55)
                                    fixup = TRUE, alpha = 1)#, palette = NULL, rev = FALSE)
 
 IOHanalyzer_env$used_colorscheme <- Set3
+IOHanalyzer_env$alg_colors <- NULL
 
 #' Set the colorScheme of the IOHanalyzer plots
 #' 
@@ -176,49 +177,98 @@ IOHanalyzer_env$used_colorscheme <- Set3
 #' \item Default
 #' \item Variant 1
 #' \item Variant 2
+#' \item Variant 3
 #' }
 #' And it is also possible to select "Custom", which allows uploading of a custom set of colors
+#' @param algnames The names of the algorithms for which to set the colors
 #' @param path The path to the file containing the colors to use. Only used if 
 #' schemename is "Custom"
-#' 
+#'  
 #' @export
 #' 
 #' @examples
-#' set_color_scheme("Default")
-set_color_scheme <- function(schemename, path = NULL){
-  if (schemename == "Default") IOHanalyzer_env$used_colorscheme <- Set3
-  else if (schemename == "Variant 1") IOHanalyzer_env$used_colorscheme <- Set2
-  else if (schemename == "Variant 2") IOHanalyzer_env$used_colorscheme <- Set1
+#' set_color_scheme("Default", get_algId(dsl))
+set_color_scheme <- function(schemename, algnames, path = NULL){
+  if (schemename == "Default") {
+    options(IOHanalyzer.max_colors = 2)
+  }
   else if (schemename == "Custom" && !is.null(path)) {
     colors <- fread(path, header = F)[[1]]
     N <- length(colors)
+    options(IOHanalyzer.max_colors = N)
     custom_set <- function(n) {
       return(colors[mod(seq(n), N) + 1])
     }
     IOHanalyzer_env$used_colorscheme <- custom_set
   } 
+  else {
+    if (schemename == "Variant 1") IOHanalyzer_env$used_colorscheme <- Set1
+    else if (schemename == "Variant 2") IOHanalyzer_env$used_colorscheme <- Set2
+    else if (schemename == "Variant 3") IOHanalyzer_env$used_colorscheme <- Set3
+    options(IOHanalyzer.max_colors = length(algnames))
+  }
+  create_color_scheme(algnames)
+}
+
+create_color_scheme <- function(algnames) {
+  if (length(algnames) == 0) {
+    return(NULL)
+  }
+  colors <- color_palettes(length(algnames))
+  linestyles <- rep(c("solid", "dash", "dot"), ceiling(length(colors)/3))[1:length(colors)]
+  IOHanalyzer_env$alg_colors <- data.table(algnames, colors, linestyles)
 }
 
 #' Get colors according to the current colorScheme of the IOHanalyzer
 #' 
-#' @param n Number of colors to get
+#' @param algnames_in List of algorithms for which to get colors
 #' 
 #' @export
 #' 
 #' @examples
-#' get_color_scheme(5)
-get_color_scheme <- function(n){
-  IOHanalyzer_env$used_colorscheme(n)
+#' get_color_scheme(get_algId(dsl))
+get_color_scheme <- function(algnames_in){
+  if (is.null(IOHanalyzer_env$alg_colors))
+    create_color_scheme(algnames_in)
+  cdt <- IOHanalyzer_env$alg_colors
+  colors <- subset(cdt, algnames %in% algnames_in)[['colors']]
+  if (is.null(colors) || length(colors) != length(algnames_in)) {
+    return(color_palettes(length(algnames_in)))
+  }
+  return(colors)
+}
+
+
+#' Get line styles according to the current styleScheme of the IOHanalyzer
+#' 
+#' @param algnames_in List of algorithms for which to get linestyles
+#' 
+#' @export
+#' 
+#' @examples
+#' get_line_style(get_algId(dsl))
+get_line_style <- function(algnames_in){
+  if (is.null(IOHanalyzer_env$alg_colors))
+    create_color_scheme(algnames_in)
+  cdt <- IOHanalyzer_env$alg_colors
+  linestyles <- subset(cdt, algnames %in% algnames_in)[['linestyles']]
+  if (is.null(linestyles) || length(linestyles) != length(algnames_in)) {
+    return(rep(c("solid", "dash", "dot"), ceiling(length(algnames_in)/3))[1:length(algnames_in)])
+  }
+  return(linestyles)
 }
 
 # TODO: incoporate more colors
 color_palettes <- function(ncolor) {
   # TODO: FIX IT!
-  if (ncolor < 5) return(IOHanalyzer_env$used_colorscheme(ncolor))
+  max_colors <- getOption("IOHanalyzer.max_colors", 2)
+  if (ncolor <= max_colors) return(IOHanalyzer_env$used_colorscheme(ncolor))
 
   brewer <- function(n) {
     colors <- RColorBrewer::brewer.pal(n, 'Spectral')
     colors[colors == "#FFFFBF"] <- "#B2B285"
+    colors[colors == "#E6F598"] <- "#86FF33"
+    colors[colors == '#FEE08B'] <- "#FFFF33"
     colors
   }
 
@@ -243,9 +293,6 @@ color_palettes <- function(ncolor) {
   colors
 }
 
-# TODO: we have to change the working directory back and force because
-# function 'orca' always generates figures in the current folder
-
 #' Save plotly figure in multiple format
 #'
 #' NOTE: This function requires orca to be installed, and for pdf and eps formats
@@ -253,23 +300,25 @@ color_palettes <- function(ncolor) {
 #'
 #' @param p plotly object. The plot to be saved
 #' @param file String. The name of the figure file
-#' @param format String. The format of the figure: 'svg', 'pdf', 'eps', 'png' are supported
+#' @param width Optional. Width of the figure
+#' @param height Optional. Height of the figure
 #' @param ... Additional arguments for orca
 #' @export
 #' @examples
 #' \donttest{
 #' p <- Plot.RT.Single_Func(dsl[1])
-#' save_plotly(p, 'example_file.png', format = 'png')
+#' save_plotly(p, 'example_file.png')
 #' }
-save_plotly <- function(p, file, format = 'svg', ...) {
+save_plotly <- function(p, file, width = NULL, height = NULL, ...) {
   des <- dirname(file)
   file <- basename(file)
+  format <- tools::file_ext(file)
   
   pwd <- tempdir()
-  width <- getOption("IOHanalyzer.figure_width", default = NULL)
-  height <- getOption("IOHanalyzer.figure_height", default = NULL)
+  if (is.null(width)) width <- getOption("IOHanalyzer.figure_width", default = NULL)
+  if (is.null(height)) height <- getOption("IOHanalyzer.figure_height", default = NULL)
   
-  if (format %in% c('svg', 'png'))
+  if (format %in% c('svg', 'png', 'jpeg', 'webp', 'pdf', 'eps'))
     withr::with_dir(pwd, orca(p, file, format = format, width = width, height = height, ...))
   else {
     file_svg <- paste0(file, '.svg')
@@ -285,4 +334,4 @@ save_plotly <- function(p, file, format = 'svg', ...) {
     )
   }
   file.rename(file.path(pwd, file), file.path(des, file))
-}
\ No newline at end of file
+}
