@@ -1,10 +1,11 @@
-format <- NULL         # the unique format of the data set
-sub_sampling <- TRUE   # perform sub-sampling of the data set?
+# active_suite <- NULL         # the unique format of the data set
+# sub_sampling <- TRUE   # perform sub-sampling of the data set?
 repo_dir <- ''         # repository directory
 repo_data <- NULL      # repository data
 has_rendered_ERT_per_fct <- FALSE
-# Formatter for function values
-format_FV <- function(v) format(v, digits = 2, nsmall = 2)
+# Formatter for function values. Somewhat overkill with as.numeric, but this prevents unneeded precision
+format_FV <- function(v) as.numeric(format(v, digits = getOption("IOHanalyzer.precision", 2), 
+                                nsmall = getOption("IOHanalyzer.precision", 2)))
 format_RT <- function(v) as.integer(v)
 
 # directory where data are extracted from the zip file
@@ -12,17 +13,20 @@ exdir <- file.path(tempdir(), 'data')
 
 setTextInput <- function(session, id, name, alternative) {
   v <- REG[[id]]
-  if (name %in% names(v)) {
+  if (name %in% names(v)) 
     updateTextInput(session, id, value = v[[name]])
-  } else
+  else
     updateTextInput(session, id, value = alternative)
 }
 
 #TODO: this function could be made more clear
-set_format_func <- function(format){
-  format_FV <<- ifelse((format == COCO || format == BIBOJ_COCO),
-                       function(v) format(v, format = 'e', digits = 3, nsmall = 2),
-                       function(v) format(v, digits = 2, nsmall = 2))
+set_format_func <- function(suite) {
+   if (grepl("\\w*bbob\\w*", suite, ignore.case = T))
+     format_FV <- function(v) as.numeric(format(v, format = 'e', digits = getOption("IOHanalyzer.precision", 2),
+                                     nsmall = getOption("IOHanalyzer.precision", 2)))
+   else  
+     format_FV <- function(v) as.numeric(format(v, digits = getOption("IOHanalyzer.precision", 2),
+                                     nsmall = getOption("IOHanalyzer.precision", 2)))
 }
 
 # register previous text inputs, which is used to restore those values
@@ -45,7 +49,7 @@ shinyServer(function(input, output, session) {
     # close_connection()
     unlink(exdir, recursive = T)
   })
-
+  
   for (f in list.files('server', pattern = '.R', full.names = T)) {
     source(f, local = TRUE)
   }
