@@ -8,8 +8,7 @@ output$RTPMF.Bar.Download <- downloadHandler(
     eval(FIG_NAME_RT_PMF)
   },
   content = function(file) {
-    save_plotly(render_RT_PMF(), file,
-                format = input$RTPMF.Bar.Format)
+    save_plotly(render_RT_PMF(), file)
   },
   contentType = paste0('image/', input$RTPMF.Bar.Format)
 )
@@ -35,22 +34,22 @@ output$RTPMF.Hist.Download <- downloadHandler(
     eval(FIG_NAME_RT_HIST)
   },
   content = function(file) {
-    save_plotly(render_RT_HIST(), file,
-                format = input$RTPMF.Hist.Format)
+    save_plotly(render_RT_HIST(), file)
   },
   contentType = paste0('image/', input$RTPMF.Hist.Format)
 )
 
 render_RT_HIST <- reactive({
   req(input$RTPMF.Hist.Target)
-  withProgress({
-  ftarget <- format_FV(input$RTPMF.Hist.Target) %>% as.numeric
-  plot_mode <- input$RTPMF.Hist.Mode
-
-  # TODO: remove 'DataSetList' in the future
-  data <- subset(DATA(), algId %in% input$RTPMF.Hist.Algs)
   
-  Plot.RT.Histogram(data, ftarget, plot_mode = plot_mode, use.equal.bins = input$RTPMF.Hist.Equal)
+  withProgress({
+    ftarget <- format_FV(input$RTPMF.Hist.Target) %>% as.numeric
+
+    # TODO: remove 'DataSetList' in the future
+    data <- subset(DATA(), algId %in% input$RTPMF.Hist.Algs)
+  
+    Plot.RT.Histogram(data, ftarget, plot_mode = input$RTPMF.Hist.Mode, 
+                      use.equal.bins = input$RTPMF.Hist.Equal)
   },
   message = "Creating plot")
 })
