@@ -36,6 +36,7 @@ fv_per_fct_box <- function(width = 12, collapsible = T, collapsed = T) {
                     label = 'Scale y axis \\(\\log_{10}\\)',
                     value = T),
 
+      hr(),
       selectInput('FCEPlot.Format', label = 'Select the figure format',
                   choices = supported_fig_format, selected = 'pdf'),
 
@@ -127,12 +128,17 @@ fv_comparison_box <- function(width = 12, collapsible = T, collapsed = T) {
           checkboxInput('FCEPlot.Aggr.Logy',
                         label = 'Scale y axis \\(\\log_{10}\\)',
                         value = F),
-          actionButton("FCEPlot.Aggr.Refresh", "Refresh the figure"),
+          actionButton("FCEPlot.Aggr.Refresh", "Refresh the figure and table"),
           # textInput('FCEPlot.Aggr.Targets', label = 'Choose the runtimes (comma-separated)'),
+          hr(),
           selectInput('FCEPlot.Aggr.Format', label = 'Select the figure format',
                       choices = supported_fig_format, selected = 'pdf'),
 
-          downloadButton('FCEPlot.Aggr.Download', label = 'Download the figure')
+          downloadButton('FCEPlot.Aggr.Download', label = 'Download the figure'),
+          hr(),
+          selectInput('FCEPlot.Aggr.TableFormat', label = 'Select the table format',
+                      choices = c('csv','tex'), selected = 'csv'),
+          downloadButton('FCEPlot.Aggr.DownloadTable', label = 'Download the table')
         ),
 
         mainPanel(
@@ -140,7 +146,12 @@ fv_comparison_box <- function(width = 12, collapsible = T, collapsed = T) {
           column(
             width = 12, align = "center",
             plotlyOutput.IOHanalyzer('FCEPlot.Aggr.Plot'),
-            DT::dataTableOutput("FCEPlot.Aggr.Targets")
+            hr(),
+            HTML_P("The chosen budget values per function are as follows (double click an entry to edit it):"),
+            DT::dataTableOutput("FCEPlot.Aggr.Targets"),
+            hr(),
+            HTML_P("The raw function-values are:"),
+            DT::dataTableOutput("FCEPlot.Aggr.FCETable")
           )
         )
       )
