@@ -8,6 +8,7 @@ fv_overview_box <- function(width = 12, collapsible = T, collapsed = T) {
 
         selectInput('FCESummary.Overview.Algid', 'Algorithms', choices = NULL, selected = NULL),
         #TODO: implement this button
+        hr(),
         selectInput('FCESummary.Overview.Format', 'Format', choices = c('csv','tex'), selected = 'csv'),
         downloadButton("FCESummary.Overview.Download", "Save this table")
       ),
@@ -34,6 +35,7 @@ fv_stats_box <- function(width = 12, collapsible = T, collapsed = T) {
                                                            Once toggled, only \\(B_{\\text{min}}\\) is
                                                            used to generate the table on the right.</p>'), value = FALSE),
         selectInput('FCESummary.Statistics.Algid', 'Algorithms', choices = NULL, selected = NULL),
+        hr(),
         selectInput('FCESummary.Statistics.Format', 'Format', choices = c('csv','tex'), selected = 'csv'),
         downloadButton("FCESummary.Statistics.Download", "Save this table")
       ),
@@ -41,7 +43,7 @@ fv_stats_box <- function(width = 12, collapsible = T, collapsed = T) {
       mainPanel(
         width = 9,
         HTML(paste0('<div style="font-size:120%;">',
-                    includeMarkdown('RMD/TAR_SUMMARY_TABLE.Rmd'),
+                    includeMarkdown('markdown/TAR_SUMMARY_TABLE.Rmd'),
                     '</div>')),
         DT::dataTableOutput('FCE_SUMMARY')
       )
@@ -69,6 +71,7 @@ fv_sample_box <- function(width = 12, collapsible = T, collapsed = T) {
 
       selectInput('FCESummary.Sample.Format', 'Format of the table',
                   choices = c('long', 'wide'), selected = 'wide'),
+      hr(),
       selectInput('FCESummary.Sample.FileFormat', 'File-Format', choices = c('csv','tex'), selected = 'csv'),
       downloadButton("FCESummary.Sample.Download", "Save the aligned runtime samples")
     ),
