@@ -6,9 +6,9 @@ upload_box <- function(width = 12, collapsible = T, collapsed = T,   # TODO: fin
     solidHeader = T, status = "primary", 
     sidebarPanel(
       width = 12,
-      selectInput('upload.data_format', 
+      selectInput('upload.data_format',
                   label = "Please choose the format of your datasets",
-                  choices = c(AUTOMATIC, TWO_COL), 
+                  choices = c(AUTOMATIC, TWO_COL),
                   selected = AUTOMATIC, width = '60%') %>%
         shinyInput_label_embed(
           custom_icon("info") %>%
@@ -16,12 +16,11 @@ upload_box <- function(width = 12, collapsible = T, collapsed = T,   # TODO: fin
               title = "The IOHprofiler, COCO and Nevergrad formats can be automatically detected."
             )
         ),
-      
-      selectInput('upload.maximization', 
+
+      selectInput('upload.maximization',
                   label = "Maximization or minimization?",
-                  choices = c(AUTOMATIC,"MAXIMIZE", "MINIMIZE"), 
+                  choices = c(AUTOMATIC,"MAXIMIZE", "MINIMIZE"),
                   selected = AUTOMATIC, width = '60%') ,
-      HTML('<p style="font-size:100%;"> <b>Note</b>: when using two-column format, please select the format and maximization manually.</p>'),
       
       HTML('<p align="justify" style="font-size:120%;">When the dataset is huge, 
            the alignment can take a very long time. In this case, you could toggle 
@@ -84,27 +83,37 @@ repository_box <- function(width = 12, collapsible = F, collapsed = T,
     solidHeader = T, status = "primary",  
     sidebarPanel(
       width = 12,
+      
+      HTML_P("Load the data from the available repositories. There are currently three available sources:
+             <ul>
+                <li>
+                  Data generated with the PBO-suite, implemented in the <a href=https://github.com/IOHprofiler/IOHexperimenter>IOHexperimenter</a>
+                </li>
+                <li>
+                  All data generated by the <a href=https://github.com/facebookresearch/nevergrad>nevergrad</a> benchmarking framework
+                </li>
+                <li>
+                  The majority of the publicly available benchmark data on the single-objective <a href=https://github.com/numbbo/coco>BBOB</a> framework
+                </li>"),
+      
+      selectInput('repository.type', label = "Select the dataset source",
+                  choices = c("PBO", "NEVERGRAD", "BBOB"), selected = "PBO", width = '50%'),
+      
       selectInput('repository.dataset', 
                   label = "Select the dataset",
-                  choices = NULL, selected = NULL, width = '50%') %>%
-        shinyInput_label_embed(
-          custom_icon() %>%
-            bs_embed_popover(
-              title = "Datasets", content = "These datasets contain data generated by the IOHexperimenter", placement = "left"
-            )
-        ),
+                  choices = NULL, selected = NULL, width = '50%', multiple = F),
 
       selectInput('repository.funcId', 
                   label = "Please choose the function",
-                  choices = NULL, selected = NULL, width = '50%'),
+                  choices = NULL, selected = NULL, width = '50%', multiple = T),
       
       selectInput('repository.dim', 
                   label = "Please choose the dimension",
-                  choices = NULL, selected = NULL, width = '50%'),
+                  choices = NULL, selected = NULL, width = '50%', multiple = T),
       
       selectInput('repository.algId', 
                   label = "Please choose the algorithm",
-                  choices = NULL, selected = NULL, width = '50%'),
+                  choices = NULL, selected = NULL, width = '50%', multiple = T),
       
       shinyjs::disabled(
         actionButton('repository.load_button', 'load data')
@@ -113,3 +122,19 @@ repository_box <- function(width = 12, collapsible = F, collapsed = T,
   )
 }
 
+welcome_bar <- function(width = 12, collapsible = T, collapsed = F) {
+  box(
+    title = HTML('<p style="font-size:140%;">Welcome to IOHanalyzer!</p>'),
+    width = width, collapsed = collapsed, collapsible = collapsible,
+    solidHeader = T, status = "primary",  
+    mainPanel(
+      width = 12, 
+      HTML(paste0(
+        '<font size="4">',
+        includeMarkdown('markdown/welcome.md'),
+        '</font>')
+      )
+    )
+  )
+}
+
