@@ -62,11 +62,11 @@ NumericVector c_impute(NumericVector x, NumericVector y, NumericVector rowname)
 }
 
 // [[Rcpp::export]]
-NumericMatrix c_impute_runtime(NumericVector index, // index value recorded
-                               NumericMatrix value, // value to align: runtime + parameters
-                               NumericVector FV,    // function values to match
-                               bool maximization    // the data are collected from a maximization problem?
-                               ) {
+NumericMatrix c_impute_running_time(NumericVector index, // index value recorded
+                                    NumericMatrix value, // value to align: runtime + parameters
+                                    NumericVector FV,    // function values to match
+                                    bool maximization    // the data are collected from a maximization problem?
+                                    ) {
   int N = FV.size();
   int L = index.size();
   int M = value.ncol();
@@ -94,8 +94,8 @@ NumericMatrix c_impute_runtime(NumericVector index, // index value recorded
   return res;
 }
 
-//TODO: Better comments
-//' Align a dataSetList by runtime
+// TODO: Better comments
+//' Align a list of data set by function values
 //'
 //' @param data the data
 //' @param FV Function values
@@ -104,11 +104,10 @@ NumericMatrix c_impute_runtime(NumericVector index, // index value recorded
 //' @param idxTarget index of the target
 //' @noRd
 // [[Rcpp::export]]
-List c_align_runtime(List data, NumericVector FV, NumericVector idxValue, bool maximization, int idxTarget) {
+List c_align_running_time(List data, NumericVector FV, NumericVector idxValue, bool maximization, int idxTarget) {
   int NC = data.size();
   int NR = FV.size();
   int M = idxValue.size();
-  // int idxTarget = 2;
 
   List res(M);
   for (int i = 0; i < M; i++) {
@@ -125,7 +124,7 @@ List c_align_runtime(List data, NumericVector FV, NumericVector idxValue, bool m
       value(_, j) = d(_, idxValue[j]);
     }
 
-    NumericMatrix tmp = c_impute_runtime(d(_, idxTarget), value, FV, maximization);
+    NumericMatrix tmp = c_impute_running_time(d(_, idxTarget), value, FV, maximization);
 
     for (int k = 0; k < M; k++) {
       NumericMatrix aux = res[k];
